moniplot package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   moniplot.lib

Submodules
----------

moniplot.biweight module
------------------------

.. automodule:: moniplot.biweight
   :members:
   :undoc-members:
   :show-inheritance:

moniplot.image\_to\_xarray module
---------------------------------

.. automodule:: moniplot.image_to_xarray
   :members:
   :undoc-members:
   :show-inheritance:

moniplot.mon\_plot module
-------------------------

.. automodule:: moniplot.mon_plot
   :members:
   :undoc-members:
   :show-inheritance:

moniplot.tol\_colors module
---------------------------

.. automodule:: moniplot.tol_colors
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: moniplot
   :members:
   :undoc-members:
   :show-inheritance:
